<?php declare(strict_types=1);

namespace App\Controller;

use Symfony\Component\Form\FormInterface;
use App\Entity\Flash;
use App\Form\FlashType;
use Symfony\Bundle\FrameworkBundle\Controller\AbstractController;
use Symfony\Component\Routing\Annotation\Route;
use Symfony\Component\HttpFoundation\Request;

/**
 * Flash controller.
 */
#[Route(path: 'flash')]
class FlashController extends AbstractController
{
	use FormControllerTrait;
	protected const ENTITY = Flash::class;
	protected const FORM = FlashType::class;
	/**
	 * Lists all flash entities.
	 */
	#[Route(path: '/', name: 'flash_index', methods: ['GET'])]
	public function indexAction()
	{
		return $this->itemListView('flash/index.html.twig', 'flashes');
	}
	/**
	 * Creates a new flash entity.
	 */
	#[Route(path: '/new', name: 'flash_new', methods: ['GET', 'POST'])]
	public function newAction(Request $request)
	{
		return $this->itemCreate($request, 'flash/new.html.twig', 'flash', 'flash_show');
	}
	/**
	 * Finds and displays a flash entity.
	 */
	#[Route(path: '/{id}', name: 'flash_show', methods: ['GET'])]
	public function showAction(Flash $flash)
	{
		return $this->itemView($flash, 'flash/show.html.twig', 'flash');
	}
	/**
	 * Displays a form to edit an existing flash entity.
	 */
	#[Route(path: '/{id}/edit', name: 'flash_edit', methods: ['GET', 'POST'])]
	public function editAction(Request $request, Flash $flash)
	{
		return $this->itemUpdate($request, $flash, 'flash/edit.html.twig', 'flash', 'flash_show');
	}
	/**
	 * Deletes a flash entity.
	 */
	#[Route(path: '/{id}', name: 'flash_delete', methods: ['DELETE'])]
	public function deleteAction(Request $request, Flash $flash)
	{
		return $this->itemDelete($request, $flash, 'flash_index');
	}
	/**
	 * Creates a form to delete a flash entity.
	 *
	 * @param Flash $flash The flash entity
	 *
	 * @return FormInterface The form
	 */
	private function createDeleteForm(Flash $flash)
	{
		return $this->buildForm($flash, 'flash_delete', 'DELETE');
	}
}
